#
# spec file for package python-python-engineio
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-engineio
Version:        4.12.0
Release:        1.1
Summary:        EngineIO server
License:        MIT
URL:            http://github.com/miguelgrinberg/python-engineio/
Source:         https://github.com/miguelgrinberg/python-engineio/archive/v%{version}.tar.gz#/python-engineio-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module simple-websocket >= 0.10.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-simple-websocket
Recommends:     python-eventlet
Suggests:       python-aiohttp >= 3.4
Suggests:       python-requests >= 2.21.0
Suggests:       python-websocket-client >= 0.54.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiohttp >= 3.4}
BuildRequires:  %{python_module eventlet}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.21.0}
BuildRequires:  %{python_module tornado}
BuildRequires:  %{python_module websocket-client >= 0.54.0}
# /SECTION
%python_subpackages

%description
Python implementation of the Engine.IO realtime server.

%prep
%autosetup -p1 -n python-engineio-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# FIXME: disable the static files tests because the tests/async/files is missing from
# the release tarball. Hence those tests will always fail.
%pytest -rs -k 'not test_logger and not test_static_file_routing and not test_static_files and not testserver'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/engineio
%{python_sitelib}/python_engineio-%{version}*-info

%changelog
* Wed Apr 16 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 4.12.0
  * Optimize packet parsing to avoid unnecessary calls to
    JSON parser (#399)
  * Pass `environ` as a second argument to callable option
    `cors_allowed_origins` #398)
* Sun Mar 23 2025 Axel Braun <axel.braun@gmx.de>
- version 4,11,2
  * Fix incorrect disconnection reason reported when browser page is closed (commit)
  * Remove debugging prints :blush: (commit)
  * Pass a reason argument to the disconnect handler #393 (commit)
  * Add maxPayload to connection response #392 (commit) (thanks HeySMMReseller & HeySMMProvider!)
  * Client option to disable timestamps in connection URLs #386 (commit)
  * Return disconnected sessions as 400 errors #391 (commit)
  * Handle unicode errors in ASGI driver #389 (commit)
  * Replaced deprecated get_event_loop with get_running_loop #384 (commit)
  * Remove constructs required by older, now unsupported Python versions (commit)
  * Switched to pyenv-asyncio for async unit tests (commit)
  * Adopted unittest.mock.AsyncMock in async unit tests instead of homegrown version (commit)
  * Removed tests dependency on unittest.TestCase base class (commit)
* Fri Nov  8 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add missing dependency python-simple-websocket
* Fri Oct 18 2024 Dirk Müller <dmueller@suse.com>
- update to 4.10.1:
  * Reject request with incorrect transport #367 (commit)
  * Reject requests with incorrect transport #367 (commit)
  * Fixed runtime error when disconnecting all clients #368
    (commit)
  * More flexible handling of the ASGI path #359 (commit)
  * Remove unused parameter in log message #377 (commit)
  * Minor updates to the server and client documentation (commit)
  * Add Python 3.13 CI builds (commit)
  * Run tests with mocked eventlet to avoid 3.13 failures
    (commit)
* Wed Aug 14 2024 Guang Yee <gyee@suse.com>
- Update to version 4.8.0
  * Return consistent responses after Websocket connection ends
  * Migrate Python package metadata to pyproject.toml
  * Remove Python 3.7 from builds
  * Internal code restructure (no functional changes)
- Drop python-311.patch as it is included upstream
* Fri Dec  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add %%{?sle15_python_module_pythons}
* Tue Feb 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-311.patch to support python 3.11,
  gh#miguelgrinberg/python-engineio@ac3911356fbe
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.3.4
  * Let companion ASGI app handle lifespan events #287 (commit)
  * Use configured request timeout when making a WebSocket connection #286 (commit) (thanks jpfarias!)
- Update to version 4.3.3
  * Handle ASGI lifespan when running with a secondary ASGI app #284 (commit) (thanks mozartilize!)
  * Update deprecated usage of asyncio.wait() #281 (commit) (thanks Ben Beasley!)
  * Better handling of queued WebSocket messages in uWSGI #256 (commit)
  * Gracefully fail to decode empty packets #269 (commit)
  * Only attempt to set an async signal handler once #276 (commit)
- Update to version 4.3.2
  * Option to use a callable for cors_allowed_origins #264 (commit)
  * Close aiohttp session when disconnecting #272 (commit)
  * Remove 3.6 and pypy-3.6 builds, add 3.10 and pypy-3.8 (commit)
* Wed Jan 19 2022 Axel Braun <axel.braun@gmx.de>
- version 4.3.1
  * Fix support for Sanic v21.9.0 and up (commit) (thanks 13g10n!)
  * Include example code in flake8 pass (commit)
  * Remove unused version constant #262 (commit 1 commit 2)
  * Backward incompatible change: Reject websocket messages larger than max_http_buffer_size #260 (commit)
  * Enable or disable specific transports #259 (commit) (thanks Maciej Szeptuch!)
  * Option to disable the SIGINT handler in the client (commit)
  * Support binary packets with zero length #257 (commit)
  * Improve documentation on start_background_task() function (commit)
  * Remove unsanitized client input from error messages #250 (commit) (thanks André Carvalho!)
  * Use plaintext Content-Type when using polling #248 (commit) (thanks Tobias!)
  * Return better error messages for client connection errors #243 (commit)
  * Reuse the aiohttp client session on reconnects #226 (commit)
  * Support setting socketio_path to the root URL #242 (commit)
  * Use the gevent selector to avoid 1024 file handle limitation of select#228 (commit)
  * Pass reason when closing a WebSocket connection (commit)
  * Improved project structure (commit)
  * Remove executable permissions from files that lack shebang lines #240 (commit) (thanks Ben Beasley!)
* Tue May 25 2021 Ben Greiner <code@bnavigator.de>
- Update to 4.2.0
  * large changelog: see CHANGES.md
* Sun May 16 2021 Axel Braun <axel.braun@gmx.de>
- python2 build removed
* Sun Nov 29 2020 John Vandenberg <jayvdb@gmail.com>
- Convert to single spec
- Remove merged patch CVE-2019-13611.patch
- Activate test suite
- Update to v3.14.1
* Tue Aug 13 2019 eapodaca@suse.com
- Add patch CVE-2019-13611.patch (SOC-9989) (bsc#1141676)
  * python-python-engineio: An issue was discovered in
    python-engineio through 3.8.2. There is a Cross-Site WebSocket
    Hijacking (CSWSH) vulnerability that allows attackers to make
    WebSocket connections to a server
* Thu Feb  1 2018 gsmith@suse.com
- Initial version 2.0.2
